==> racer-0.0.1.tgz: package/examples/todos/client.js <==
var racer, todoHtml;
racer = require('racer');
todoHtml = require('./shared').todoHtml;
$(racer.ready(function() {
  var checkChanged, checkChangedDelayed, checkShortcuts, content, lastHtml, listPath, model, newTodo, overlay, todoList, updateOverlay;
  model = racer.model;
  newTodo = $('#new-todo');
  todoList = $('#todos');
  content = $('#content');
  overlay = $('#overlay');
  listPath = '_group.todoList';
  updateOverlay = function() {
    return overlay.html(model.socket.socket.connected ? '' : '<p id=info>Offline<span id=reconnect> &ndash; <a href=# onclick="return todos.connect()">Reconnect</a></span>');
  };
  model.socket.on('disconnect', function() {
    return setTimeout(updateOverlay, 200);
  });
  model.socket.on('connect', updateOverlay);
  setTimeout(updateOverlay, 400);
  model.on('fatalError', function() {
    return overlay.html('<p id=info>Unable to reconnect &ndash; <a href=javascript:window.location.reload()>Reload</a>');
  });
  model.on('push', listPath, function(value) {
    return todoList.append(todoHtml(value));
  });
  model.on('insertBefore', listPath, function(index, value) {
    return todoList.children().eq(index).before(todoHtml(value));
  });
  model.on('set', '_group.todos.*.completed', function(id, value) {
    $("#" + id).toggleClass('completed', value);
    return $("#check" + id).prop('checked', value);
  });
  model.on('remove', listPath, function(_arg) {
    var id;
    id = _arg.id;
    return $("#" + id).remove();
  });
  model.on('move', listPath, function(_arg, to) {
    var id, index, target;
    id = _arg.id, index = _arg.index;
    target = todoList.children().get(to);
    if (id.toString() === target.id) {
      return;
    }
    if (index > to && to !== -1) {
      return $("#" + id).insertBefore(target);
    } else {
      return $("#" + id).insertAfter(target);
    }
  });
  model.on('set', '_group.todos.*.text', function(id, value) {
    var el;
    el = $("#text" + id);
    if (el.is(':focus')) {
      return;
    }
    return el.html(value);
  });
  window.todos = {
    connect: function() {
      var reconnect;
      reconnect = document.getElementById('reconnect');
      reconnect.style.display = 'none';
      setTimeout((function() {
        return reconnect.style.display = 'inline';
      }), 1000);
      model.socket.socket.connect();
      return false;
    },
    addTodo: function() {
      var i, list, text, todo, _len, _ref;
      if (!(text = newTodo.val())) {
        return;
      }
      newTodo.val('');
      _ref = list = model.get(listPath);
      for (i = 0, _len = _ref.length; i < _len; i++) {
        todo = _ref[i];
        if (todo.completed) {
          break;
        }
      }
      todo = {
        id: model.incr('_group.nextId'),
        completed: false,
        text: text
      };
      if (i === list.length) {
        return model.push(listPath, todo);
      } else {
        return model.insertBefore(listPath, i, todo);
      }
    },
    check: function(checkbox, id) {
      model.set("_group.todos." + id + ".completed", checkbox.checked);
      if (checkbox.checked) {
        return model.move(listPath, {
          id: id
        }, -1);
      }
    },
    del: function(id) {
      return model.remove(listPath, {
        id: id
      });
    }
  };
  todoList.sortable({
    handle: '.handle',
    axis: 'y',
    containment: '#dragbox',
    update: function(e, ui) {
      var item, to;
      item = ui.item[0];
      to = todoList.children().index(item);
      return model.move(listPath, {
        id: item.id
      }, to);
    }
  });
  lastHtml = '';
  checkChanged = function(e) {
    var html, id, target, text;
    html = content.html();
    if (html === lastHtml) {
      return;
    }
    lastHtml = html;
    target = e.target;
    if (!(id = target.getAttribute('data-id'))) {
      return;
    }
    text = target.innerHTML;
    return model.set("_group.todos." + id + ".text", text);
  };
  checkChangedDelayed = function(e) {
    return setTimeout(checkChanged, 10, e);
  };
  checkShortcuts = function(e) {
    var code, command;
    if (!(e.metaKey || e.ctrlKey)) {
      return;
    }
    code = e.which;
    if (!(command = 
      code === 66 ? 'bold' :
      code === 73 ? 'italic' :
      code === 32 ? 'removeFormat' :
      code === 220 ? 'removeFormat' : null)) {
      return;
    }
    document.execCommand(command, false, null);
    if (e.preventDefault) {
      e.preventDefault();
    }
    return false;
  };
  content.keydown(checkShortcuts).keydown(checkChanged).keyup(checkChanged).bind('paste', checkChangedDelayed).bind('dragover', checkChangedDelayed);
  document.execCommand('useCSS', false, true);
  return document.execCommand('styleWithCSS', false, false);
}));
racer.init(this.init);
delete this.init;

==> racer-0.0.4.tgz: package/examples/todos/client.js <==
var racer, todoHtml;
racer = require('racer');
todoHtml = require('./shared').todoHtml;
$(racer.ready(function() {
  var checkChanged, checkChangedDelayed, checkShortcuts, content, lastHtml, listPath, model, newTodo, overlay, todoList;
  model = racer.model;
  newTodo = $('#new-todo');
  todoList = $('#todos');
  content = $('#content');
  overlay = $('#overlay');
  listPath = '_group.todoList';
  model.on('connectionStatus', function(connection) {
    return overlay.html(connection ? '' : connection === false ? '<p id=info>Offline<span id=reconnect> &ndash; <a href=# onclick="return todos.connect()">Reconnect</a></span>' : '<p id=info>Unable to reconnect &ndash; <a href=javascript:window.location.reload()>Reload</a>');
  });
  model.on('push', listPath, function(value) {
    return todoList.append(todoHtml(value));
  });
  model.on('insertBefore', listPath, function(index, value) {
    return todoList.children().eq(index).before(todoHtml(value));
  });
  model.on('set', '_group.todos.*.completed', function(id, value) {
    $("#" + id).toggleClass('completed', value);
    return $("#check" + id).prop('checked', value);
  });
  model.on('remove', listPath, function(_arg) {
    var id;
    id = _arg.id;
    return $("#" + id).remove();
  });
  model.on('move', listPath, function(_arg, to) {
    var id, index, target;
    id = _arg.id, index = _arg.index;
    target = todoList.children().get(to);
    if (id.toString() === target.id) {
      return;
    }
    if (index > to && to !== -1) {
      return $("#" + id).insertBefore(target);
    } else {
      return $("#" + id).insertAfter(target);
    }
  });
  model.on('set', '_group.todos.*.text', function(id, value) {
    var el;
    el = $("#text" + id);
    if (el.is(':focus')) {
      return;
    }
    return el.html(value);
  });
  window.todos = {
    connect: function() {
      var reconnect;
      reconnect = document.getElementById('reconnect');
      reconnect.style.display = 'none';
      setTimeout((function() {
        return reconnect.style.display = 'inline';
      }), 1000);
      model.socket.socket.connect();
      return false;
    },
    addTodo: function() {
      var i, list, text, todo, _len, _ref;
      if (!(text = newTodo.val())) {
        return;
      }
      newTodo.val('');
      _ref = list = model.get(listPath);
      for (i = 0, _len = _ref.length; i < _len; i++) {
        todo = _ref[i];
        if (todo.completed) {
          break;
        }
      }
      todo = {
        id: model.incr('_group.nextId'),
        completed: false,
        text: text
      };
      if (i === list.length) {
        return model.push(listPath, todo);
      } else {
        return model.insertBefore(listPath, i, todo);
      }
    },
    check: function(checkbox, id) {
      model.set("_group.todos." + id + ".completed", checkbox.checked);
      if (checkbox.checked) {
        return model.move(listPath, {
          id: id
        }, -1);
      }
    },
    del: function(id) {
      return model.remove(listPath, {
        id: id
      });
    }
  };
  todoList.sortable({
    handle: '.handle',
    axis: 'y',
    containment: '#dragbox',
    update: function(e, ui) {
      var item, to;
      item = ui.item[0];
      to = todoList.children().index(item);
      return model.move(listPath, {
        id: item.id
      }, to);
    }
  });
  lastHtml = '';
  checkChanged = function(e) {
    var html, id, target, text;
    html = content.html();
    if (html === lastHtml) {
      return;
    }
    lastHtml = html;
    target = e.target;
    if (!(id = target.getAttribute('data-id'))) {
      return;
    }
    text = target.innerHTML;
    return model.set("_group.todos." + id + ".text", text);
  };
  checkChangedDelayed = function(e) {
    return setTimeout(checkChanged, 10, e);
  };
  checkShortcuts = function(e) {
    var code, command;
    if (!(e.metaKey || e.ctrlKey)) {
      return;
    }
    code = e.which;
    if (!(command = 
      code === 66 ? 'bold' :
      code === 73 ? 'italic' :
      code === 32 ? 'removeFormat' :
      code === 220 ? 'removeFormat' : null)) {
      return;
    }
    document.execCommand(command, false, null);
    if (e.preventDefault) {
      e.preventDefault();
    }
    return false;
  };
  content.keydown(checkShortcuts).keydown(checkChanged).keyup(checkChanged).bind('paste', checkChangedDelayed).bind('dragover', checkChangedDelayed);
  document.execCommand('useCSS', false, true);
  return document.execCommand('styleWithCSS', false, false);
}));
racer.init(this.init);
delete this.init;
